==> vgk_game_services-2.1.3.tar.gz: lib/vgk_game_services.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

const String _CHANNEL_NAME = "vgk_game_services";
const String _SUCCESS = "success";
const String _RESPONSE = "response";
const String _MESSAGE = "message";
const String _ID = "id";
const String _DISPLAY_NAME = "displayName";
const String _NAME = "name";
const String _DESCRIPTION = "description";
const String _SNAPSHOT_DATA = "snapshotData";
const String _SCORE = "score";
const String _PERCENT = "percent";

class Methods {
  static const String getSignIn = "getSignIn";
  static const String showLeaderboard = "showLeaderboard";
  static const String submitScore = "submitScore";
  static const String showAchievements = "showAchievements";
  static const String unlockAchievement = "unlockAchievement";
  static const String setPercentAchievement = "setPercentAchievement";
  static const String loadSnapShot = "loadSnapShot";
  static const String saveSnapShot = "saveSnapShot";
}

class Account {
  late String id;
  late String displayName;
}

class SignInResult {
  late Account account;
  late String message;
  late bool success;
}

class VgkGameServices {
  static const MethodChannel _channel = const MethodChannel(_CHANNEL_NAME);

  static Future<SignInResult> get signIn async {
    SignInResult result = new SignInResult();
    try {
      final Map<dynamic, dynamic> _response =
          await _channel.invokeMethod(Methods.getSignIn);
      result.success = _response[_RESPONSE] == _SUCCESS;
      result.message = _response[_MESSAGE];
      if (result.success) {
        result.account = Account()
          ..id = _response[_ID]
          ..displayName = _response[_DISPLAY_NAME];
      }
    } catch (e) {
      debugPrint('signIn error ::::  ${e.toString()}');
      result.success = false;
      return result;
    }
    return result;
  }

  static Future<SignInResult> loadSnapShot(String name) async {
    SignInResult result = new SignInResult();
    try {
      final String response =
          await _channel.invokeMethod(Methods.loadSnapShot, {_NAME: name});
      result.message = response;
      result.success = true;
      if (result.message == "Error") {
        result.success = false;
      }
      debugPrint('loadSnapShot success ::::');
    } catch (e) {
      debugPrint('loadSnapShot error ::::  ${e.toString()}');
      result.success = false;
    }
    return result;
  }

  static Future<SignInResult> saveSnapShot(
      String name, String description, String snapshotData) async {
    SignInResult result = new SignInResult();
    try {
      final String response = await _channel.invokeMethod(
          Methods.saveSnapShot, {
        _NAME: name,
        _DESCRIPTION: description,
        _SNAPSHOT_DATA: snapshotData
      });
      result.message = response;
      result.success = true;
      if (result.message == "Error") {
        result.success = false;
      }
      debugPrint('saveSnapShot success ::::');
    } catch (e) {
      debugPrint('saveSnapShot error ::::  ${e.toString()}');
      result.success = false;
    }
    return result;
  }

  static Future<bool> showLeaderboard(String id) async {
    try {
      final String response =
          await _channel.invokeMethod(Methods.showLeaderboard, {_ID: id});
      if (response == _SUCCESS) return true;
    } catch (e) {
      debugPrint('showLeaderboard error ::::  ${e.toString()}');
      return false;
    }
    return false;
  }

  static Future<bool> submitScore(
      {required String id, required int score}) async {
    try {
      final String response = await _channel
          .invokeMethod(Methods.submitScore, {_ID: id, _SCORE: score});
      if (response == _SUCCESS) return true;
    } catch (e) {
      debugPrint('submitScore error ::::  ${e.toString()}');
      return false;
    }
    return false;
  }

  static Future<bool> showAchievements() async {
    try {
      final String response =
          await _channel.invokeMethod(Methods.showAchievements);
      if (response == _SUCCESS) return true;
    } catch (e) {
      debugPrint('showAchievements error ::::  ${e.toString()}');
      return false;
    }
    return false;
  }

  static Future<bool> unlockAchievement(String id) async {
    try {
      final String response =
          await _channel.invokeMethod(Methods.unlockAchievement, {_ID: id});
      if (response == _SUCCESS) return true;
    } catch (e) {
      debugPrint('unlockAchievement error ::::  ${e.toString()}');
      return false;
    }
    return false;
  }

  static Future<bool> setPercentAchievement(
      {required String id, required double percent}) async {
    try {
      final String response = await _channel.invokeMethod(
          Methods.setPercentAchievement, {
        _ID: id,
        _PERCENT: Platform.isAndroid ? percent.ceil().toInt() : percent
      });
      if (response == _SUCCESS) return true;
    } catch (e) {
      debugPrint('setPercentAchievement error ::::  ${e.toString()}');
      return false;
    }
    return false;
  }
}

==> vgk_game_services-2.1.7.tar.gz: lib/vgk_game_services.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

const String _CHANNEL_NAME = "vgk_game_services";
const String _SUCCESS = "success";
const String _RESPONSE = "response";
const String _MESSAGE = "message";
const String _ID = "id";
const String _DISPLAY_NAME = "displayName";
const String _NAME = "name";
const String _DESCRIPTION = "description";
const String _SNAPSHOT_DATA = "snapshotData";
const String _SCORE = "score";
const String _PERCENT = "percent";

class Methods {
  static const String getSignIn = "getSignIn";
  static const String showLeaderboard = "showLeaderboard";
  static const String submitScore = "submitScore";
  static const String showAchievements = "showAchievements";
  static const String unlockAchievement = "unlockAchievement";
  static const String setPercentAchievement = "setPercentAchievement";
  static const String loadSnapShot = "loadSnapShot";
  static const String saveSnapShot = "saveSnapShot";
}

class Account {
  late String id;
  late String displayName;
}

class SignInResult {
  late Account account;
  late String message;
  late bool success;
}

class VgkGameServices {
  static const MethodChannel _channel = const MethodChannel(_CHANNEL_NAME);

  static Future<SignInResult> get signIn async {
    SignInResult result = new SignInResult();
    try {
      final Map<dynamic, dynamic> _response =
          await _channel.invokeMethod(Methods.getSignIn);
      result.success = _response[_RESPONSE] == _SUCCESS;
      result.message = _response[_MESSAGE];
      if (result.success) {
        result.account = Account()
          ..id = _response[_ID]
          ..displayName = _response[_DISPLAY_NAME];
      }
    } catch (e) {
      // debugPrint('signIn error ::::  ${e.toString()}');
      result.success = false;
      return result;
    }
    return result;
  }

  static Future<SignInResult> loadSnapShot(String name) async {
    SignInResult result = new SignInResult();
    try {
      final String response =
          await _channel.invokeMethod(Methods.loadSnapShot, {_NAME: name});
      result.message = response;
      result.success = true;
      if (result.message == "Error") {
        result.success = false;
      }
    } catch (e) {
      result.success = false;
    }
    return result;
  }

  static Future<SignInResult> saveSnapShot(
      String name, String description, String snapshotData) async {
    SignInResult result = new SignInResult();
    try {
      final String response = await _channel.invokeMethod(
          Methods.saveSnapShot, {
        _NAME: name,
        _DESCRIPTION: description,
        _SNAPSHOT_DATA: snapshotData
      });
      result.message = response;
      result.success = true;
      if (result.message == "Error") {
        result.success = false;
      }
    } catch (e) {
      result.success = false;
    }
    return result;
  }

  static Future<bool> showLeaderboard(String id) async {
    try {
      final String response =
          await _channel.invokeMethod(Methods.showLeaderboard, {_ID: id});
      if (response == _SUCCESS) return true;
    } catch (e) {
      return false;
    }
    return false;
  }

  static Future<bool> submitScore(
      {required String id, required int score}) async {
    try {
      final String response = await _channel
          .invokeMethod(Methods.submitScore, {_ID: id, _SCORE: score});
      if (response == _SUCCESS) return true;
    } catch (e) {
      return false;
    }
    return false;
  }

  static Future<bool> showAchievements() async {
    try {
      final String response =
          await _channel.invokeMethod(Methods.showAchievements);
      if (response == _SUCCESS) return true;
    } catch (e) {
      return false;
    }
    return false;
  }

  static Future<bool> unlockAchievement(String id) async {
    try {
      final String response =
          await _channel.invokeMethod(Methods.unlockAchievement, {_ID: id});
      if (response == _SUCCESS) return true;
    } catch (e) {
      return false;
    }
    return false;
  }

  static Future<bool> setPercentAchievement(
      {required String id, required double percent}) async {
    try {
      final String response = await _channel.invokeMethod(
          Methods.setPercentAchievement, {
        _ID: id,
        _PERCENT: Platform.isAndroid ? percent.ceil().toInt() : percent
      });
      if (response == _SUCCESS) return true;
    } catch (e) {
      return false;
    }
    return false;
  }
}
